import { useEffect, useState } from 'react'
import { IValutions } from '../../models/IValutions'
import { valuations } from '../../utils/Constants'
import { ConverterInput } from './ConverterInput/ConverterInput'
import { actualDate, getRelationToCurrency } from '../../utils/HelperFunctions'

import './Converter.scss'

export const Converter = () => {
  const [isFocus, setFocus] = useState<1 | 2>(1)
  const [firstValue, setFirstValue] = useState<string>('1')
  const [secondValue, setSecondValue] = useState<string>('1')
  const [firstValuation, setFirstValuation] = useState<IValutions>(
    valuations[0]
  )
  const [secondValuation, setSecondValuation] = useState<IValutions>(
    valuations[1]
  )

  const swap = () => {
    setSecondValuation(firstValuation)
    setFirstValuation(secondValuation)
  }

  useEffect(() => {
    if (isFocus === 1) {
      getRelationToCurrency(
        firstValuation.title,
        secondValuation.title,
        +firstValue,
        setSecondValue
      )
    } else if (isFocus === 2) {
      getRelationToCurrency(
        secondValuation.title,
        firstValuation.title,
        +secondValue,
        setFirstValue
      )
    }
  }, [isFocus, firstValue, firstValuation, secondValue, secondValuation])

  useEffect(() => {
    if (firstValuation.title === secondValuation.title) {
      let index = valuations.findIndex(
        (item) => item.title !== firstValuation.title
      )
      setSecondValuation(valuations[index])
    }
  }, [firstValuation])

  useEffect(() => {
    if (secondValuation.title === firstValuation.title) {
      let index = valuations.findIndex(
        (item) => item.title !== secondValuation.title
      )
      setFirstValuation(valuations[index])
    }
  }, [secondValuation])

  useEffect(() => {
    const interval = setInterval(() => {
      getRelationToCurrency(
        firstValuation.title,
        secondValuation.title,
        +firstValue,
        setSecondValue
      )
    }, 25000)
    return () => clearInterval(interval)
  }, [])

  const outputResult = () =>
    `${firstValue || 0} ${firstValuation.title} = ${secondValue || 0} ${
      secondValuation.title
    }`

  return (
    <div className='converter'>
      <div className='converter__body'>
        <ConverterInput
          valuation={firstValuation}
          value={firstValue}
          setValuation={setFirstValuation}
          setValue={setFirstValue}
          index={1}
          setFocus={setFocus}
        />
        <div className='converter__row'>
          <div className={'converter__arrow'} onClick={swap} />
        </div>
        <ConverterInput
          valuation={secondValuation}
          value={secondValue}
          setValuation={setSecondValuation}
          setValue={setSecondValue}
          index={2}
          setFocus={setFocus}
        />
      </div>
      <footer className='converter__footer'>
        <div className='converter__title'>{outputResult()}</div>
        Данные носят ознакомительный характер · {'\t'}
        <b>{actualDate()}</b>
      </footer>
    </div>
  )
}
